CLI Typer
=========

.. automodule:: oduit.cli_typer
   :members:
   :undoc-members:
   :show-inheritance:

Functions
---------

.. autofunction:: oduit.cli_typer.create_global_config
.. autofunction:: oduit.cli_typer.with_config
.. autofunction:: oduit.cli_typer.cli_main

Commands
--------

.. autofunction:: oduit.cli_typer.run
.. autofunction:: oduit.cli_typer.shell
.. autofunction:: oduit.cli_typer.install
.. autofunction:: oduit.cli_typer.update
.. autofunction:: oduit.cli_typer.test
.. autofunction:: oduit.cli_typer.create_db
.. autofunction:: oduit.cli_typer.create_addon
.. autofunction:: oduit.cli_typer.list_addons
.. autofunction:: oduit.cli_typer.export_lang
.. autofunction:: oduit.cli_typer.print_config_cmd
